#include <Wt/WApplication>
#include <Wt/WContainerWidget>
#include <Wt/WGridLayout>
#include <Wt/WSlider>
#include <Wt/WStackedWidget>
#include <Wt/WText>

class TwoSlidersApplication : public Wt::WApplication
{
  public:

    TwoSlidersApplication (Wt::WEnvironment const & wEnvironment)
      : Wt::WApplication (wEnvironment)
    {
      setTitle ("two-sliders example");
      setCssTheme ("polished");

      class WContainerWidget : public Wt::WContainerWidget
      {
        public:

          WContainerWidget (Wt::WWidget * const wWidget)
          {
            Wt::WGridLayout * const layout = new Wt::WGridLayout ();

            layout->addWidget (wWidget, 0, 0, 1, 1);
            setLayout (layout);
            setMinimumSize (300, 200);
            setMaximumSize (300, 200);
          }
      };

      class WStackedWidget : public Wt::WStackedWidget
      {
        public:

          virtual void addWidget (Wt::WWidget * const wWidget)
          {
            Wt::WStackedWidget::addWidget (wWidget);
            wWidget->setPositionScheme (Wt::Absolute);
            wWidget->setOffsets (Wt::WLength (0, Wt::WLength::Pixel), (Wt::Left | Wt::Top));

            if (count () > 0) {
              setCurrentIndex (0);

              for (int index = 1; (index < count ()); index++) {
                widget (index)->show ();
              }
            }
          }
      };

      class WSlider : public Wt::WSlider
      {
        public:

          WSlider ()
            : Wt::WSlider (Wt::Horizontal)
          {
            setMinimum (0);
            setMaximum (100);
            setTickInterval (10);
            setTickPosition (Wt::WSlider::TicksBothSides);
          }
      };

      {
        WStackedWidget * const wStackedWidget = new WStackedWidget ();

        wStackedWidget->addWidget (new Wt::WText ("hello hello ..."));
        wStackedWidget->addWidget (new Wt::WText ("again again ..."));
        root ()->addWidget (new WContainerWidget (wStackedWidget));
      }
      {
        WStackedWidget * const wStackedWidget = new WStackedWidget ();

        wStackedWidget->addWidget (new WSlider ());
        wStackedWidget->addWidget (new Wt::WText ("hello hello ..."));
        wStackedWidget->addWidget (new WSlider ());
        wStackedWidget->addWidget (new Wt::WText ("again again ..."));
        root ()->addWidget (new WContainerWidget (wStackedWidget));
      }
    }
};

Wt::WApplication * createApplication (Wt::WEnvironment const & wEnvironment)
{
  return new TwoSlidersApplication (wEnvironment);
}

int main (int argc, char ** argv)
{
  return WRun (argc, argv, &createApplication);
}

